//----------------------------------------------------------------------
/*EASTRISING TECHNOLOGY CO,.LTD.*/
// Module    : ER-EP0213-2B  2.13"  122*250 dots
// Create    : JAVEN
// Date      : 2020-06-19
// Drive IC  : UC8251
// INTERFACE : 4line Serial 
// MCU 		 : STC12LE5A60S2
// VDD		 : 3.3V  
//----------------------------------------------------------------------

#include <reg52.h>
#include <intrins.h>
sbit 	BUSY=P3^0;
sbit 	RST=P3^1;
sbit 	DC=P3^3;
sbit 	CS1=P3^4;
sbit 	SCK=P3^5;
sbit 	SDA=P3^6;

sbit	int0=P3^2;

bit log=0;

#define uchar  unsigned char
#define uint  unsigned int


//xx Private macro xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx

#define SDA_H     	(SDA=1)						
#define SDA_L     	(SDA=0)
#define SCLK_H    	(SCK=1)  					
#define SCLK_L   	(SCK=0) 
#define nCS_H     	(CS1=1)						
#define nCS_L     	(CS1=0)
#define nDC_H     	(DC=1)						
#define nDC_L     	(DC=0)
#define nRST_H     	(RES=1)						
#define nRST_L     	(RES=0)


#define DELAY_TIME	2									// DELAY TIME



#define PIC_BLACK		252
#define PIC_WHITE		255
#define PIC_A			1
#define PIC_B   	    2
#define PIC_C   	    3
#define PIC_HLINE		4
#define PIC_VLINE	    5
#define PIC_GRAY			6
#define PIC_D   	    7
#define PIC_E		    8
#define PIC_F	        9



  
#define Source_Pixel  128  
#define Gate_Pixel    250    

void lut_GC(void);//Write full brush waveform
void lut_DU(void);//Write partial brush waveform
void EPD_init(void);//Write Initialization
void PIC_display_GC(const unsigned char* picData);//full brush
void PIC_display_DU(const unsigned char* picData);//partial brush
void EPD_sleep(void);//sleep
void EPD_refresh(void);//Start refreshing the screen
void lcd_chkstatus(void);//Determine whether the screen is idle
void EPD_Reset(void);//Hardware Reset



//***************************************************************//
//LUT_Flag Calling Waveform Markers
//Border_Flag  Border Markers,Only the first screen after initialization will refresh the borderDo not brush at other times
//***************************************************************//
unsigned long LUT_Flag=0,Border_Flag=0;






//////////////////////////////////////full screen update LUT////////////////////////////////////////////

//Full refresh waveform, refresh time 800ms
const unsigned char code lut_R20_GC[] =  
{
0x01,	0x00,	0x14,	0x14,	0x01,	0x01,	0x00,	0x01,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};							  
const unsigned char code   lut_R21_GC[] =  
{
0x01,	0x60,	0x14,	0x14,	0x01,	0x01,	0x00,	0x01,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};						 
const unsigned char code   lut_R22_GC[] =  
{
0x01,	0x60,	0x14,	0x14,	0x01,	0x01,	0x00,	0x01,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};
const unsigned char code   lut_R23_GC[] =  
{
0x01,	0x90,	0x14,	0x14,	0x01,	0x01,	0x00,	0x01,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};
const unsigned char code   lut_R24_GC[] =  
{
0x01,	0x90,	0x14,	0x14,	0x01,	0x01,	0x00,	0x01,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};


// Partially refresh waveform, screen refresh time 400ms
const unsigned char code  lut_R20_DU[] =  
{
0x01,	0x00,	0x14,	0x01,	0x01,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};							  
const unsigned char code   lut_R21_DU[] =  
{
0x01,	0x20,	0x14,	0x01,	0x01,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};						 
const unsigned char code   lut_R22_DU[] =  
{
0x01,	0x80,	0x14,	0x01,	0x01,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};
const unsigned char code   lut_R23_DU[] =  
{
0x01,	0x40,	0x14,	0x01,	0x01,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};
const unsigned char  lut_R24_DU[] =  
{
0x01,	0x00,	0x14,	0x01,	0x01,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,	0x00,
};



const unsigned char code  gImage_a[4000] = { /* 0X10,0X01,0X00,0X7A,0X00,0XFA, */
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7E,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XC0,0X00,0X00,0X00,0X7F,0XFF,0XFF,0XFF,0X80,
0X7E,0X00,0X3C,0X00,0X07,0XFF,0XF0,0X0E,0X3F,0XFE,0X00,0X0F,0XFF,0XFF,0XFF,0X80,
0X7E,0X00,0X3C,0X00,0X07,0XFF,0XE7,0X9E,0X7F,0XFE,0X00,0X80,0XFF,0XFF,0XFF,0X80,
0X7F,0X7B,0XFC,0X00,0X07,0XFF,0X8F,0XBC,0XFF,0XFC,0X07,0XF8,0X3F,0XFF,0XFF,0X80,
0X7E,0X79,0XFC,0X00,0X07,0XFF,0X3F,0X39,0XFF,0XF8,0X0F,0XFF,0XDF,0XFF,0XFF,0X80,
0X7E,0X01,0XFF,0XFC,0X0F,0XFE,0X7F,0X7B,0XFF,0XF0,0X1E,0X7F,0X07,0XFF,0XFF,0X80,
0X7F,0X03,0XFF,0XF0,0X3F,0XFC,0XFF,0X73,0XFF,0XF0,0X38,0XF0,0X2B,0XFF,0XFF,0X80,
0X7F,0X87,0XFF,0XC0,0X7F,0XF9,0XFE,0X77,0XFF,0XF0,0X33,0XE3,0XFB,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0X81,0XFF,0XF9,0XFE,0XF7,0XFF,0XE0,0X07,0X0F,0XFB,0XFF,0XFF,0X80,
0X7F,0XFF,0XFE,0X07,0XFF,0XFB,0XFE,0XE7,0XFF,0XE0,0XEE,0X78,0X3B,0XFF,0XFF,0X80,
0X7F,0X01,0XFC,0X00,0X07,0XF3,0XFE,0XEF,0XFF,0XC0,0XE4,0XC1,0X9B,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0X00,0X07,0XF7,0XFE,0XCF,0XFF,0X80,0XF1,0X8F,0X9B,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0X00,0X07,0XE7,0XFC,0XDF,0XFF,0X81,0XE3,0X3F,0X9B,0XFF,0XFF,0X80,
0X7E,0X7F,0XFC,0X00,0X07,0XE7,0XFC,0XDF,0XFF,0X01,0XEE,0X7F,0X97,0XFF,0XFF,0X80,
0X7F,0X7F,0XFF,0XFF,0XFF,0XE7,0XFD,0XDF,0XFF,0X03,0XCC,0XFF,0X97,0XFF,0XFF,0X80,
0X7E,0X01,0XFF,0XFF,0XFF,0XE7,0XFD,0XDF,0XFE,0X03,0XD9,0XFF,0X97,0XFF,0XFF,0X80,
0X7E,0X01,0XFF,0XFF,0XFF,0XE7,0XFD,0X9F,0XFC,0X07,0X99,0XFF,0X37,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0X00,0X47,0XE7,0XF9,0XBF,0XFC,0X07,0XBB,0XFF,0X37,0XFF,0XFF,0X80,
0X7F,0XFF,0XFC,0X00,0X47,0XEF,0XF9,0XBF,0XFC,0X07,0X93,0XFF,0X2F,0XFF,0XFF,0X80,
0X73,0XFD,0XFC,0X00,0X47,0XEF,0XF9,0XBF,0XFC,0X07,0X3B,0XFF,0X6F,0XFF,0XFF,0X80,
0X73,0XE1,0XFC,0X00,0X47,0XEF,0XF9,0XBF,0XF8,0X0F,0XB3,0XFF,0X6F,0XFF,0XFF,0X80,
0X73,0X01,0XFF,0XFF,0XFF,0XEF,0XFB,0XBF,0XF8,0X0F,0X37,0XFE,0X6F,0XFF,0XFF,0X80,
0X70,0X07,0XFF,0XFF,0XFF,0XCF,0XFB,0X3F,0XF0,0X0F,0XB7,0XFE,0X4F,0XFF,0XFF,0X80,
0X70,0X3F,0XFF,0XFF,0XFF,0XCF,0XFB,0X3F,0XF0,0X1F,0XA7,0XFE,0X5F,0XFF,0XFF,0X80,
0X7C,0X07,0XFC,0X00,0X07,0XCF,0XF3,0X3F,0XE0,0X1F,0X97,0XFE,0XDF,0XFF,0XFF,0X80,
0X7F,0X01,0XFC,0X00,0X07,0XCF,0XF3,0X3F,0XE0,0X1F,0XB7,0XFC,0X9F,0XFF,0XFF,0X80,
0X7F,0XE1,0XFC,0X00,0X07,0XCF,0XF3,0X3F,0XE0,0X3F,0XD7,0XFE,0XBF,0XFF,0XFF,0X80,
0X7F,0XFD,0XFC,0X00,0X07,0XCF,0XF3,0X7F,0XE0,0X3F,0XD3,0XCC,0XBF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0X83,0XFF,0XCF,0XF3,0X7F,0XC0,0X3F,0XC3,0XCD,0X3F,0XFF,0XFF,0X80,
0X7F,0X87,0XFF,0XC1,0XFF,0XCF,0XF7,0X7F,0XC0,0X3F,0XEB,0XCD,0X7F,0XFF,0XFF,0X80,
0X7F,0X03,0XFF,0X00,0XFF,0XCF,0XF6,0X7F,0X80,0X7F,0XE1,0XFC,0X7F,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0X00,0X7F,0XCF,0XF6,0X7F,0X80,0X7F,0XF5,0XEC,0X7F,0XFF,0XFF,0X80,
0X7E,0X79,0XFC,0X08,0X7F,0XCF,0XF6,0X7F,0X80,0X7F,0XF2,0XEC,0X7F,0XFF,0XFF,0X80,
0X7F,0X7B,0XFC,0X1C,0X7F,0XCF,0XF6,0X7F,0X00,0XFF,0XFA,0X6C,0XFF,0XFF,0XFF,0X80,
0X7E,0X00,0X3C,0X7E,0X7F,0XCF,0XF6,0X7F,0X00,0XFF,0XF9,0X2C,0XFF,0XFF,0XFF,0X80,
0X7E,0X00,0X3D,0XFF,0X7F,0XCF,0XE6,0X7F,0X00,0XFF,0XFE,0X2C,0XFF,0XFF,0XFF,0X80,
0X7E,0X00,0X3F,0X83,0XFF,0XCF,0XE6,0XFF,0X00,0XFF,0XFE,0X20,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0X01,0XFF,0XCF,0XE6,0XFE,0X00,0XFF,0XFF,0X00,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFE,0X00,0XFF,0XCF,0XE6,0XFE,0X00,0XFF,0XFF,0X81,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0X3C,0X00,0X7F,0XCF,0XE6,0XFE,0X01,0XFF,0XFF,0X82,0XFF,0X0F,0XFF,0X80,
0X7E,0X01,0X3C,0X24,0X7F,0XDF,0XE4,0XFC,0X01,0XFF,0XFF,0XE2,0XFC,0X77,0XFF,0X80,
0X7E,0X01,0X3C,0X64,0X7F,0XDF,0XEC,0XFC,0X01,0XFF,0XFF,0XE6,0XF9,0XBB,0XFF,0X80,
0X7F,0XFF,0XFC,0X64,0X7F,0XDF,0XEC,0XFC,0X03,0XFF,0XFF,0XE6,0X64,0X0D,0XFF,0X80,
0X7F,0XFF,0XFC,0X64,0X7F,0XDF,0XCC,0XF8,0X03,0XFF,0XFF,0XE3,0X52,0X86,0XFF,0X80,
0X7F,0X63,0XFC,0X20,0X7F,0XDF,0XCC,0XF8,0X03,0XFF,0XFF,0XC8,0X24,0X62,0XFF,0X80,
0X7E,0X41,0XFE,0X20,0XFF,0XDF,0XED,0XF0,0X03,0XFF,0XFF,0XCE,0X09,0XF1,0X7F,0X80,
0X7E,0XC1,0XFF,0X20,0XFF,0XDF,0XCD,0XF0,0X03,0XFF,0XFF,0X90,0X17,0XF9,0X3F,0X80,
0X7E,0XCD,0XFF,0XA3,0XFF,0XDF,0XCD,0XF0,0X03,0XFF,0XFF,0X0E,0X2F,0XFA,0XBF,0X80,
0X7E,0X0D,0XFF,0XFF,0XFF,0XDF,0XD9,0XF0,0X07,0XFF,0XFF,0X5F,0X1F,0XF8,0XDF,0X80,
0X7E,0X09,0XFF,0XFF,0XFF,0X9F,0XDB,0XE0,0X07,0XFF,0XFE,0X7F,0X1F,0XFC,0X5F,0X80,
0X7F,0X1B,0XFF,0XFF,0XFF,0X9F,0XDB,0XE0,0X0F,0XFF,0XFE,0X3F,0X9F,0XFE,0X5F,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0X9F,0X9B,0XE0,0X0F,0XFF,0XFC,0X39,0X9F,0XFF,0X6F,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0X9F,0X9B,0XE0,0X0F,0XFF,0XFD,0XF1,0X0F,0XFE,0X2F,0X80,
0X70,0X01,0XFF,0XFF,0XFF,0X9F,0X97,0XC0,0X0F,0XFF,0XF9,0XF9,0X1F,0XF9,0X2F,0X80,
0X70,0X01,0XFF,0XFF,0XFF,0X9F,0XB7,0XC0,0X0F,0XFF,0XFA,0XFE,0X9F,0XE1,0XB7,0X80,
0X70,0X01,0XFF,0XFF,0XFF,0X9F,0XA7,0XC0,0X0F,0XFF,0XF0,0XFE,0X9F,0X8C,0X17,0X80,
0X7F,0X7B,0XFF,0XFF,0XFF,0X9F,0XA7,0X80,0X0F,0XFF,0XF1,0XFC,0XBF,0X1E,0XDB,0X80,
0X7E,0X79,0XFF,0X9E,0X1F,0X9F,0XA7,0XC0,0X07,0XFF,0XE7,0XFF,0X3C,0X7E,0X4B,0X80,
0X7E,0X01,0XFE,0X1C,0X0F,0X1F,0X2F,0X80,0X07,0XFF,0XE7,0XFB,0X79,0XFF,0X4D,0X80,
0X7F,0X03,0XFE,0X18,0X0F,0X3F,0X2F,0X80,0X07,0XFF,0XC7,0XFA,0X63,0XFF,0X85,0X80,
0X7F,0X87,0XFC,0X18,0X07,0X3F,0X2F,0X00,0X03,0XFF,0XC7,0XF6,0XCF,0XFF,0XB4,0X80,
0X7F,0XFF,0XFC,0X30,0XC7,0X3F,0X5F,0X00,0X00,0XFF,0XDF,0XE4,0X9F,0XFF,0XC2,0X80,
0X7F,0XFF,0XFC,0X70,0XC7,0X3F,0X5F,0X00,0X00,0X00,0X8E,0X05,0X3F,0XFF,0XCB,0X80,
0X7E,0X00,0X3C,0X71,0XC7,0X7F,0X5F,0X00,0X00,0X00,0X8E,0X19,0X9F,0XFF,0XE5,0X80,
0X7E,0X00,0X3C,0X61,0X87,0X7F,0X5F,0X00,0X00,0X01,0X3F,0XCB,0XDF,0XFF,0XF4,0X80,
0X7E,0X00,0X3C,0X01,0X06,0X7E,0X9F,0X00,0X00,0X03,0X1F,0XD3,0XE7,0XFF,0XF2,0X80,
0X7F,0XFF,0XFE,0X03,0X0E,0X7E,0X9F,0X80,0X00,0X02,0X3F,0XA7,0XF7,0XFF,0XFA,0X80,
0X7F,0XFF,0XFE,0X03,0X0E,0XFE,0X9F,0XC0,0X00,0X08,0X7F,0XAF,0XF3,0XFF,0XF9,0X80,
0X7F,0X33,0XFF,0X87,0X3E,0XFE,0X9F,0XC0,0X00,0X1F,0X1F,0X4F,0XF9,0XFF,0XF9,0X80,
0X7E,0X11,0XFF,0XFF,0XFE,0XFE,0X9F,0XC0,0X00,0X7F,0XCE,0X5F,0XF9,0XFF,0XF8,0X80,
0X7E,0X11,0XFF,0XFF,0XFE,0XFC,0X9F,0XF0,0X00,0XFF,0XE3,0X9F,0XFD,0XFF,0XE1,0X80,
0X7E,0X49,0XFC,0X00,0X06,0XFC,0X9F,0XF8,0X01,0XFF,0XF9,0X3F,0XFC,0XFF,0X87,0X80,
0X7F,0X49,0XFC,0X00,0X06,0XFC,0XBF,0XFE,0X0F,0X1F,0XFC,0X7F,0XFE,0XFE,0X0F,0X80,
0X7E,0X01,0XFC,0X00,0X04,0XFD,0XBF,0XFF,0XFF,0X67,0XFE,0X7F,0XFE,0X70,0X3F,0X80,
0X7E,0X01,0XFC,0X00,0X04,0XFD,0XBF,0XFF,0XFF,0X9B,0XFE,0X3F,0XFF,0X60,0XFF,0X80,
0X7E,0X03,0XFF,0XFC,0XFC,0XFD,0XBF,0XFF,0XFF,0XC0,0X7F,0XBF,0XFF,0X03,0XFF,0X80,
0X7F,0XFF,0XFF,0XFC,0X7D,0XFD,0X3F,0XFF,0XFF,0X80,0XDF,0XCF,0XFF,0X0F,0XFF,0X80,
0X73,0XFD,0XFC,0X00,0X7D,0XFD,0X3F,0XFF,0XFF,0X86,0X1F,0XE7,0XF0,0X7F,0XFF,0X80,
0X73,0XE1,0XFC,0X00,0X7D,0XFD,0X3F,0XFF,0XFF,0X47,0X37,0XF0,0X07,0XFF,0XFF,0X80,
0X73,0X01,0XFC,0X00,0X7D,0XFD,0X3F,0XFF,0XFF,0X0F,0XC4,0XF0,0X5F,0XFF,0XFF,0X80,
0X70,0X07,0XFC,0X00,0XF9,0XFD,0X3F,0XFF,0XFE,0X2E,0XE2,0X77,0X7F,0XFF,0XFF,0X80,
0X70,0X3F,0XFF,0XFF,0XF9,0XFD,0X3F,0XFF,0XFE,0XAC,0X08,0X27,0X7F,0XFF,0XFF,0X80,
0X7C,0X07,0XFF,0XFF,0XF9,0XFD,0X3F,0XFF,0XFD,0X19,0X90,0X0F,0XBF,0XFF,0XFF,0X80,
0X7F,0X01,0XFF,0X83,0XF9,0XF9,0X3F,0XFF,0XFD,0X1D,0XC3,0X67,0X3F,0XFF,0XFF,0X80,
0X7F,0XE1,0XFF,0X01,0XF9,0XF9,0X3F,0XFF,0XFA,0X3C,0X1F,0XC0,0X3F,0XFF,0XFF,0X80,
0X7F,0XFD,0XFE,0X00,0XF9,0XFB,0X3F,0XFF,0XFE,0XFC,0X7F,0X0F,0X3F,0XFF,0XFF,0X80,
0X7F,0XFF,0XFC,0X00,0X79,0XFD,0X3F,0XFF,0XFC,0X71,0XFC,0X7F,0X3F,0XFF,0XFF,0X80,
0X7E,0X3F,0XFC,0X38,0X79,0XFD,0X3F,0XFF,0XF4,0X07,0XE0,0X02,0X5F,0XFF,0XFF,0X80,
0X7E,0X3F,0XFC,0X7C,0X79,0XFD,0X3F,0XFF,0XE0,0X7F,0X87,0X08,0X1F,0XFF,0XFF,0X80,
0X7E,0X3F,0XFC,0X7C,0X79,0XF9,0X3F,0XFF,0XC3,0XFF,0X27,0X3C,0XAF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFC,0X38,0X79,0XF9,0X3F,0XFF,0X9F,0XFC,0X73,0XBE,0X0F,0XFF,0XFF,0X80,
0X7F,0XFF,0XFC,0X00,0X79,0XF9,0X3F,0XFF,0X3F,0XF8,0XF3,0X9F,0X5F,0XFF,0XFF,0X80,
0X7F,0X87,0XFE,0X00,0XF9,0XF9,0X3F,0XFF,0X7F,0XC2,0X71,0X9F,0X1F,0XFF,0XFF,0X80,
0X7F,0X03,0XFF,0X01,0XFF,0XF9,0X3F,0XFF,0X88,0X1F,0X2C,0X9F,0XBF,0XFF,0XFF,0X80,
0X7E,0X01,0XFF,0X83,0XF9,0XF9,0X3F,0XFF,0X81,0X5F,0X8E,0X0F,0XDF,0XFF,0XFF,0X80,
0X7E,0X79,0XFF,0XFF,0XF9,0XF9,0X3F,0XFF,0X87,0XE7,0XCC,0X4F,0XDF,0XFF,0XFF,0X80,
0X7E,0X79,0XFF,0X83,0XF9,0XF9,0XBF,0XFF,0X57,0XF3,0XE1,0X87,0XDF,0XFF,0XFF,0X80,
0X7E,0X31,0XFF,0X01,0XF9,0XF9,0XBF,0XFE,0X07,0XC3,0XF3,0X37,0XDF,0XFF,0XFF,0X80,
0X7F,0X33,0XFE,0X00,0XF9,0XF9,0XBF,0XFE,0X0F,0XCC,0XFA,0X73,0X9F,0XFF,0XFF,0X80,
0X7F,0XB7,0XFC,0X00,0X7B,0XF9,0XBF,0XD3,0X3F,0XDE,0X78,0XF3,0XBF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFC,0X24,0X7B,0XF9,0X9A,0X90,0X38,0XDF,0X39,0XFB,0X3F,0XFF,0XFF,0X80,
0X7F,0XFF,0XFC,0X64,0X79,0XF9,0X82,0X09,0X42,0X0F,0X18,0X72,0X7F,0XFF,0XFF,0X80,
0X7F,0X87,0XFC,0X64,0X79,0XF9,0X80,0X1F,0X07,0X0B,0X43,0XA4,0XFF,0XFF,0XFF,0X80,
0X7F,0X03,0XFC,0X64,0X7D,0XF9,0X9F,0XFE,0XB7,0XC2,0X47,0X85,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0X20,0X7D,0XF9,0X9F,0XFE,0X27,0XC0,0XAF,0XFB,0XFF,0XFF,0XFF,0X80,
0X7E,0X79,0XFE,0X20,0XFD,0XF9,0X9F,0XFE,0X33,0XF1,0XA7,0XE7,0XFF,0XFF,0XFF,0X80,
0X7E,0X79,0XFF,0X20,0XFC,0XFD,0XDF,0XFE,0X7B,0XF1,0X7B,0X8F,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0XFF,0XA3,0XFC,0XFD,0XDF,0XFC,0XF9,0XF8,0X7C,0X3F,0XFF,0XFF,0XFF,0X80,
0X7F,0X03,0XFF,0XFF,0XFC,0XFD,0XCF,0XFC,0X74,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0X87,0XFF,0X71,0XFC,0XFD,0XCF,0XD0,0X86,0X7E,0X7F,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFE,0X60,0XFE,0XFC,0XE6,0X80,0X3F,0X9F,0X3F,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFC,0X60,0X7E,0XFC,0XE0,0X00,0XFF,0XCF,0X7F,0XFF,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0X40,0X7E,0XFC,0XE0,0X3F,0XFF,0XE7,0X7F,0XFF,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0XC6,0X7E,0XFC,0XE7,0XFF,0XFF,0XE2,0X7F,0XFF,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0XC6,0X7E,0XFE,0XE7,0XFF,0XFF,0XF0,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFB,0XFC,0XC6,0X7F,0X7E,0XF7,0XFF,0XFF,0XE3,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XF9,0XFC,0X04,0X7F,0X7E,0X77,0XFF,0XFF,0XE3,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0XFC,0X04,0X7F,0X7E,0X73,0XFF,0XFF,0XE3,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7E,0X01,0XFE,0X0C,0XFF,0X7E,0X73,0XFF,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7E,0X03,0XFF,0X1D,0XFF,0XBF,0X7B,0XFF,0XFF,0XE7,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X7F,0XFB,0XFF,0XFF,0XFF,0XBF,0X3B,0XFF,0XFF,0XE7,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X7F,0XF9,0XFF,0XFF,0XFF,0X9F,0X39,0XFF,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X99,0X80,
0X7E,0X01,0XFF,0XFF,0XFF,0X9F,0X3D,0XFF,0XFF,0XEF,0XFF,0XFF,0XFF,0XFF,0X99,0X80,
0X7E,0X01,0XFF,0XFF,0XFF,0XDF,0XBD,0XFF,0XFF,0XEF,0XFF,0XFF,0XFF,0XFF,0X99,0X80,
0X7E,0X03,0XFF,0XFF,0XFF,0XDF,0X9C,0XFF,0XFF,0XCF,0XFF,0XFF,0XFF,0XFF,0XC1,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XEF,0X9E,0XFF,0XFF,0XDF,0XFF,0XFF,0XFF,0XFF,0XC3,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XEF,0XDE,0XFF,0XFF,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XE7,0XCE,0X7F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XE7,0XEF,0X7F,0XFF,0XBF,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XF7,0XEF,0X7F,0XFF,0XBF,0XFF,0XFF,0XFF,0XFF,0X99,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFB,0XE7,0X3F,0XFF,0X7F,0XFF,0XFF,0XFF,0XFF,0X19,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFB,0XF7,0XBF,0XFF,0X7F,0XFF,0XFF,0XFF,0XFE,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFD,0XF3,0XBF,0XFF,0X7F,0XFF,0XFF,0XFF,0XFC,0XE3,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFD,0XF9,0XDF,0XFE,0XFF,0XFF,0XFF,0XFF,0XFD,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFD,0XFD,0XCF,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0X07,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFE,0X7C,0XCF,0XFD,0XFF,0XFF,0XFF,0XFF,0XFE,0X03,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0X7E,0X67,0XF9,0XFF,0XFF,0XFF,0XFF,0XFC,0X71,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0X37,0XFB,0XFF,0XFF,0XFF,0XFF,0XFC,0XF9,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0X9F,0XB3,0XF7,0XFF,0XFF,0XFF,0XFF,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XDF,0XC9,0XE7,0XFF,0XFF,0XFF,0XFF,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XEF,0XE6,0X0F,0XFF,0XFF,0XFF,0XFF,0XFC,0X71,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE7,0XF8,0X1F,0XFF,0XFF,0XFF,0XFF,0XFE,0X03,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XF3,0XFC,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0X07,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X01,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFE,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE1,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X07,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X07,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE1,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X07,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X03,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X71,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XF9,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X8F,0XFF,0XFF,0XFF,0XFC,0X71,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X87,0XFF,0XFF,0XFF,0XFE,0X03,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X83,0XFF,0XFF,0XFF,0XFF,0X07,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X91,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X9C,0X7F,0XFF,0XFF,0XFF,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X9E,0X3F,0XFF,0XFF,0XFF,0XF9,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XFF,0XFF,0XFF,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XE7,0XC7,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XCF,0X83,0XFF,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XCF,0X33,0XFF,0XF9,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XFF,0X00,0X00,0XFF,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0XCE,0X73,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XC6,0X73,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X3F,0X1F,0XE0,0XE3,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0X9F,0XF1,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X3F,0X1F,0XFF,0XFF,0XFF,0X07,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XFF,0XFF,0XFE,0X03,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0XC7,0XFF,0XFC,0X71,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XFF,0XC3,0XE7,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC1,0XF3,0XFC,0XF9,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0XC8,0XF3,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XCC,0X73,0XFC,0X71,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0XFB,0XDF,0XCE,0X03,0XFE,0X03,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X7B,0XDF,0XCE,0X07,0XFF,0X07,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X18,0X1F,0XCF,0X87,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X8C,0X3F,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE3,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF1,0XFF,0XF8,0X1F,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X0C,0X7F,0XE0,0X07,0XFF,0XE3,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X06,0X3F,0XC0,0X03,0XFF,0XC7,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0XF7,0X9F,0XC7,0XE3,0XFF,0X1F,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0XF7,0XDF,0XCF,0XF3,0XFE,0X3F,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X07,0XFF,0XC7,0XE3,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X0F,0XFF,0XC0,0X03,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC7,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC7,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC7,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X7F,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0XF1,0X8F,0XFF,0X99,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X3F,0X1F,0XE0,0X07,0XFF,0X99,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0X9F,0XCE,0X33,0XFF,0X99,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0X9F,0XCE,0X73,0XFF,0XC1,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0X9F,0XCE,0X73,0XFF,0XC3,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X3F,0X1F,0XC6,0X33,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0XE0,0X87,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,0X7F,0XF1,0X8F,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0XFF,0XFF,0XFF,0XFF,0X99,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0XFF,0X19,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0XFE,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XC7,0XF3,0XFC,0XE3,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XC1,0XF3,0XFD,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XC0,0X73,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XF8,0X13,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XFF,0X03,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XFF,0XC3,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XFF,0XF3,0XFF,0X07,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X03,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X71,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XFF,0XFF,0XFC,0XF9,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XFF,0XFF,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X1F,0XFF,0XFF,0XFC,0XF9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XFF,0XFF,0XFC,0X71,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XFF,0XFF,0XFF,0XFF,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF3,0X9F,0XFF,0XFF,0XFC,0X01,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X01,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XC9,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XC9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XC9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0XC9,0X80,
0X60,0X00,0X00,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X80,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,

};

const unsigned char code  gImage_b[4000] = {  /* 0X10,0X01,0X00,0X7A,0X00,0XFA, */
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X03,0XFF,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X0F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X1F,0XFF,0XE0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0XFF,0XF8,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0X8F,0XFC,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7C,0X00,0XFC,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7C,0X00,0X7E,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X78,0X00,0X1E,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X78,0X00,0X1F,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X78,0X00,0X0F,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X78,0X00,0X0F,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X78,0X00,0X0F,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7C,0X00,0X0F,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3E,0X00,0X0F,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3E,0X00,0X0F,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0X80,0X1F,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X0F,0X80,0X7E,0X00,
0XFF,0XFF,0XFF,0XE0,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X0F,0X80,0X7E,0X00,
0XFF,0XFF,0XFE,0X03,0XFF,0XFF,0X87,0XFC,0X0F,0XFF,0XFF,0X00,0X03,0X80,0X7C,0X00,
0XFF,0XFF,0XF0,0X3F,0XFF,0XFF,0X07,0XF8,0X07,0XFF,0XFF,0X00,0X00,0X00,0X78,0X00,
0XFF,0XFF,0XF0,0X3F,0XFF,0XFF,0X07,0XF0,0X03,0XFF,0XFF,0X00,0X00,0X00,0X60,0X00,
0XFF,0XFF,0XFE,0X03,0XFF,0XFF,0X07,0XE0,0X01,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XE0,0XFF,0XFF,0X0F,0XE0,0X01,0XFF,0XFF,0X00,0X3F,0X00,0X00,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XFE,0X0F,0XE0,0X00,0XFF,0XFF,0X00,0X3F,0XC0,0X00,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XFE,0X0F,0XC1,0XE0,0XFF,0XFF,0X00,0X7F,0XC0,0X00,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XFE,0X0F,0XC1,0XE0,0XFF,0XFF,0X00,0X7F,0XCF,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X00,0X00,0X00,0X1F,0XFF,0X00,0X79,0XCF,0X80,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X00,0X00,0X00,0X1F,0XFF,0X00,0X71,0XEF,0X80,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X02,0X00,0X00,0X1F,0XFF,0X00,0X70,0XE7,0XC0,0X00,
0XFF,0XFF,0XFC,0X1F,0XFF,0XFE,0X0F,0X03,0XE0,0XFF,0XFF,0X00,0X70,0XE3,0XC0,0X00,
0XFF,0XFF,0XF8,0X0F,0XFF,0XFE,0X07,0X07,0XE0,0XFF,0XFF,0X00,0X78,0XE1,0XC0,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFF,0X06,0X07,0XE0,0XFF,0XFF,0X00,0X7C,0XE1,0XC0,0X00,
0XFF,0XFF,0XF1,0X27,0XFF,0XFF,0X00,0X0F,0XE0,0XFF,0XFF,0X00,0X7E,0XE3,0XC0,0X00,
0XFF,0XFF,0XF3,0X27,0XFF,0XFF,0X00,0X0F,0XC0,0XFF,0XFF,0X00,0X7F,0XE7,0XC0,0X00,
0XFF,0XFF,0XF3,0X27,0XFF,0XFF,0X80,0X1F,0XC1,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XF1,0X07,0XFF,0XFF,0XC0,0X1F,0XE1,0XFF,0XFF,0X00,0X7F,0XFF,0X80,0X00,
0XFF,0XFF,0XF9,0X0F,0XFF,0XFF,0XE0,0X7F,0XF1,0XFF,0XFF,0X00,0X03,0XFF,0X80,0X00,
0XFF,0XFF,0XFD,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X7E,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X3F,0X80,0X00,0X00,0X00,
0XFF,0XFF,0XFC,0X1F,0XFF,0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0X3F,0XF8,0X00,0X00,0X00,
0XFF,0XFF,0XF8,0X0F,0XFF,0XF8,0X0F,0XE0,0X00,0X3F,0XFF,0X3F,0XFF,0XC0,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XF8,0X0F,0XE0,0X00,0X3F,0XFF,0X3F,0XFF,0XFF,0XC0,0X00,
0XFF,0XFF,0XF3,0XE7,0XFF,0XF8,0X0F,0XE0,0X00,0X3F,0XFF,0X03,0XFF,0XFF,0XC0,0X00,
0XFF,0XFF,0XF3,0XE7,0XFF,0XF8,0X0F,0XE0,0X00,0X3F,0XFF,0X00,0X1F,0XFF,0XC0,0X00,
0XFF,0XFF,0XF9,0XCF,0XFF,0XF8,0X0F,0XE0,0X00,0X3F,0XFF,0X00,0X3F,0XFF,0XC0,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XF8,0X0F,0XE0,0X00,0X3F,0XFF,0X00,0X78,0X3F,0XC0,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XF8,0X0F,0XE0,0XF8,0X3F,0XFF,0X00,0X78,0X03,0XC0,0X00,
0XFF,0XFF,0XF0,0X00,0XFF,0XF8,0X0F,0XE0,0XF8,0X3F,0XFF,0X00,0X70,0X03,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X0F,0XE0,0XF8,0X3F,0XFF,0X00,0X70,0X03,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X0F,0XC0,0XF8,0X3F,0XFF,0X00,0X78,0X03,0XC0,0X00,
0XFF,0XFF,0XF0,0X04,0XFF,0XF8,0X0F,0XC0,0XF8,0X3F,0XFF,0X00,0X78,0X03,0XC0,0X00,
0XFF,0XFF,0XF0,0X04,0XFF,0XF8,0X0F,0X80,0XF8,0X3F,0XFF,0X00,0X7E,0X03,0XC0,0X00,
0XFF,0XFF,0XF0,0X04,0XFF,0XF8,0X00,0X00,0XF8,0X3F,0XFF,0X00,0X3F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X3F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X0F,0XFF,0X80,0X00,
0XFF,0XFF,0XF8,0X07,0XFF,0XFF,0X00,0X03,0XF8,0X3F,0XFF,0X00,0X07,0XFF,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFF,0X80,0X07,0XFF,0XFF,0XFF,0X00,0X00,0X78,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFF,0XF0,0X3F,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XF3,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XF3,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0X00,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XF0,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFE,0X3F,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0X80,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFC,0X1F,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0X00,0X70,0X7F,0XC0,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0X00,0X70,0X00,0XC0,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0X00,0X70,0X00,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XF8,0X0F,0XFF,0XFF,0XFF,0XFF,0X00,0X38,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XEF,0XFF,0XFC,0X1F,0XFF,0XFF,0XFF,0XFF,0X00,0X1C,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XE7,0XFF,0XFE,0X3F,0XFF,0XFF,0XFF,0XFF,0X00,0X7E,0X00,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFE,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFE,0X00,0X00,
0XFF,0XFF,0XF0,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XEF,0XFF,0XF8,0X1F,0XFF,0XFF,0XFF,0XFF,0X00,0X0F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XE7,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X03,0XFF,0XC0,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X00,0X07,0XC0,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XF0,0X0F,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X03,0XE0,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X1F,0XF8,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0XF8,0X3F,0XFF,0X00,0X3F,0XFE,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0XF8,0X3F,0XFF,0X00,0X7F,0XFF,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0XF8,0X3F,0XFF,0X00,0X7F,0XFF,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XC0,0XF8,0X3F,0XFF,0X00,0X70,0X1F,0X80,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XC0,0XF8,0X3F,0XFF,0X00,0X70,0X07,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0X80,0XF8,0X3F,0XFF,0X00,0X70,0X03,0XC0,0X00,
0XFF,0XFF,0XFC,0XE3,0XFF,0XF8,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X70,0X03,0XC0,0X00,
0XFF,0XFF,0XF8,0XC1,0XFF,0XF8,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X78,0X03,0XC0,0X00,
0XFF,0XFF,0XF0,0X80,0XFF,0XFE,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X7C,0X03,0XC0,0X00,
0XFF,0XFF,0XF1,0X8C,0XFF,0XFF,0X80,0X03,0XF8,0X3F,0XFF,0X00,0X3C,0X07,0XC0,0X00,
0XFF,0XFF,0XF3,0X8C,0XFF,0XFF,0X80,0X07,0XFF,0XFF,0XFF,0X00,0X1C,0X0F,0X80,0X00,
0XFF,0XFF,0XF3,0X08,0XFF,0XFF,0XE0,0X3F,0XFF,0XFF,0XFF,0X00,0X1C,0X0F,0X80,0X00,
0XFF,0XFF,0XF0,0X10,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X04,0X0F,0X00,0X00,
0XFF,0XFF,0XF8,0X11,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X0E,0X00,0X00,
0XFF,0XFF,0XFC,0X33,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X78,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X7F,0XE0,0X00,0X00,
0XFF,0XFF,0XF0,0X04,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X7F,0XF8,0X00,0X00,
0XFF,0XFF,0XF0,0X04,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X7F,0XFF,0XE0,0X00,
0XFF,0XFF,0XF0,0X04,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X1F,0XFF,0XFF,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0X00,0X3F,0XFF,0X00,0X00,0XFF,0XFF,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XE0,0XF8,0X3F,0XFF,0X00,0X00,0X1F,0XFF,0X00,
0XFF,0XFF,0XF1,0XE7,0XFF,0XF8,0X1F,0XE0,0XF8,0X3F,0XFF,0X00,0X00,0X07,0XBF,0X00,
0XFF,0XFF,0XF0,0XE7,0XFF,0XF8,0X1F,0XE0,0XF8,0X3F,0XFF,0X00,0X00,0X03,0X83,0X00,
0XFF,0XFF,0XF0,0X67,0XFF,0XF8,0X1F,0XC0,0XF8,0X3F,0XFF,0X00,0X00,0X03,0X80,0X00,
0XFF,0XFF,0XF2,0X07,0XFF,0XF8,0X1F,0XC0,0XF8,0X3F,0XFF,0X00,0X00,0X03,0XC0,0X00,
0XFF,0XFF,0XF3,0X07,0XFF,0XF8,0X1F,0X80,0XF8,0X3F,0XFF,0X00,0X7E,0X03,0XC0,0X00,
0XFF,0XFF,0XF3,0X87,0XFF,0XF8,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XF3,0XE7,0XFF,0XF8,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X00,0X01,0XF8,0X3F,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X03,0XF8,0X3F,0XFF,0X00,0X07,0XFF,0X80,0X00,
0XFF,0XFF,0XFC,0X1F,0XFF,0XFF,0X80,0X07,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0X80,0X00,
0XFF,0XFF,0XF8,0X0F,0XFF,0XFF,0XF0,0X3F,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XF0,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XF1,0X27,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XF3,0X27,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X70,0X00,0X00,0X00,
0XFF,0XFF,0XF3,0X27,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XC0,0X00,0X00,
0XFF,0XFF,0XF1,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0X00,0X00,
0XFF,0XFF,0XF9,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0X80,0X00,
0XFF,0XFF,0XFD,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X3F,0XFF,0XCF,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0XFF,0XCF,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X07,0XCF,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X0F,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7C,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XC0,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XF9,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0XF0,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0XFF,0XC0,0X00,
0XFF,0XFF,0XFF,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X1F,0XC0,0X00,
0XFF,0XFF,0XFE,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X07,0X00,0X00,
0XFF,0XFF,0XF8,0X1F,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X03,0X80,0X00,
0XFF,0XFF,0XF0,0XFF,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X03,0X80,0X00,
0XFF,0XFF,0XF3,0XFF,0X87,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X03,0XC0,0X00,
0XFF,0XFF,0XE7,0XFF,0XC3,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7E,0X01,0XC0,0X00,
0XFF,0XFF,0XCF,0XFF,0XC3,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0X8F,0XC3,0XC1,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0X9F,0X83,0XF1,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XFF,0X3F,0X80,0XF0,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X07,0XFF,0X80,0X00,
0XFF,0XFE,0X3E,0X00,0XF8,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X07,0X80,0X00,
0XFF,0XFE,0X7E,0X00,0X78,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFC,0X7C,0X08,0X78,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XF8,0XFC,0X18,0X3C,0X7F,0XFF,0XC0,0X00,0X3F,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XF9,0XF8,0X3C,0X3C,0X3F,0XF0,0X00,0X00,0X3F,0XFF,0X00,0X07,0XF0,0X00,0X00,
0XFF,0XF1,0XF0,0X7E,0X3E,0X3C,0X00,0X00,0X00,0X1F,0XFF,0X00,0X1F,0XFC,0X00,0X00,
0XFF,0XF3,0XF0,0XFF,0X1E,0X00,0X03,0XFF,0XC4,0X1F,0XFF,0X00,0X3F,0XFE,0X00,0X00,
0XFF,0XE3,0XE1,0XFF,0X18,0X01,0XFF,0XFF,0XC7,0X0F,0XFF,0X00,0X3F,0XFF,0X00,0X00,
0XFF,0XE7,0XE1,0XFF,0X80,0X7F,0XFF,0XFF,0X8F,0X87,0XFF,0X00,0X7F,0XFF,0X80,0X00,
0XFF,0XC7,0XC7,0XFF,0X81,0XFF,0XFF,0XFF,0X1F,0X87,0XFF,0X00,0X78,0X0F,0X80,0X00,
0XFF,0XCF,0XC7,0XFE,0X07,0XFF,0XFF,0XFF,0X1F,0XC3,0XFF,0X00,0X70,0X07,0XC0,0X00,
0XFF,0X8F,0X8F,0XFC,0X1F,0XFF,0XFF,0XFE,0X3F,0XC3,0XFF,0X00,0X70,0X03,0XC0,0X00,
0XFF,0X8F,0X8F,0XF8,0X7F,0XFF,0XFC,0X3E,0X7F,0XE1,0XFF,0X00,0X70,0X03,0XC0,0X00,
0XFF,0X1F,0X1F,0XF0,0XFF,0XF8,0X00,0X3E,0X7F,0XE1,0XFF,0X00,0X70,0X03,0XC0,0X00,
0XFF,0X3F,0X3F,0XE1,0XFF,0X00,0X00,0X7C,0X7F,0XF1,0XFF,0X00,0X7C,0X03,0XC0,0X00,
0XFE,0X3E,0X7F,0XC3,0XFC,0X00,0X00,0X7C,0X7F,0XF0,0XFF,0X00,0X7C,0X03,0XC0,0X00,
0XFE,0X3E,0X7F,0XC7,0XF0,0X00,0X00,0X78,0X3F,0XF8,0XFF,0X00,0X3F,0X8F,0X80,0X00,
0XFE,0X7C,0XFF,0X8F,0XE0,0X00,0X00,0X78,0X3F,0XF8,0X7F,0X00,0X3F,0XFF,0X80,0X00,
0XFC,0X7C,0XFF,0X8F,0X80,0X00,0X00,0X70,0X1F,0XFC,0X7F,0X00,0X1F,0XFF,0X80,0X00,
0XFC,0X7D,0XFF,0X9F,0X00,0X00,0X00,0XF0,0X0F,0XFC,0X3F,0X00,0X07,0XFE,0X00,0X00,
0XFC,0XF9,0XFF,0X1F,0X0F,0XFF,0XFF,0XF0,0X0F,0XFC,0X3F,0X00,0X03,0XFC,0X00,0X00,
0XF8,0X7B,0XFF,0X3F,0XFF,0XFF,0XFF,0XE0,0X0F,0XFE,0X3F,0X00,0X00,0X00,0X00,0X00,
0XFC,0XFB,0XFE,0X3F,0XFF,0XFF,0XFF,0XE0,0X07,0XFE,0X1F,0X00,0X00,0X00,0X00,0X00,
0XF8,0XF7,0XFE,0X7F,0XFF,0XFF,0XFF,0XE0,0X07,0XFE,0X1F,0X00,0X00,0X00,0X00,0X00,
0XF8,0XFF,0XFC,0X7F,0XFF,0XFF,0XFF,0XC0,0X03,0XFF,0X1F,0X00,0X00,0X00,0X00,0X00,
0XF8,0XFF,0XF8,0XFF,0XFF,0XFF,0XFF,0XC0,0X03,0XFF,0X1F,0X00,0X00,0X00,0X00,0X00,
0XF8,0XFF,0XF8,0XFF,0XFF,0XFF,0XFF,0XC0,0X03,0XFF,0X0F,0X00,0X00,0X00,0X00,0X00,
0XF0,0XFF,0XF9,0XFF,0XFF,0XFF,0XFF,0XC0,0X03,0XFF,0X8F,0X00,0X00,0X00,0X00,0X00,
0XF9,0XFF,0XF1,0XFF,0XFF,0XFF,0XFF,0X80,0X03,0XFF,0X8F,0X00,0X00,0X00,0X00,0X00,
0XF0,0XFF,0XF1,0XFF,0XFF,0XFF,0XFF,0X80,0X01,0XFF,0X87,0X00,0X00,0X00,0X00,0X00,
0XF1,0XFF,0XF3,0XFF,0XFF,0XFF,0XFF,0X80,0X01,0XFF,0XC3,0X00,0X00,0X00,0X00,0X00,
0XF1,0XFF,0XF3,0XFF,0XFF,0XFF,0XFF,0X80,0X01,0XFF,0X00,0X00,0X00,0X00,0X00,0X00,
0XF1,0XFF,0XE3,0XFF,0XFF,0XFF,0XFF,0X80,0X01,0XFC,0X00,0X00,0X00,0X00,0X00,0X00,
0XF1,0XFF,0XF3,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XF0,0X00,0X00,0X00,0X00,0X00,0X00,
0XF1,0XFF,0XE3,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XE0,0X00,0X00,0X03,0XFE,0X00,0X00,
0XF1,0XFF,0XE3,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XF0,0XC6,0X00,0X0F,0XFF,0XC0,0X00,
0XE1,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFB,0XC7,0X00,0X1F,0XFF,0XE0,0X00,
0XE1,0XFF,0XC7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC7,0X00,0X3F,0XFF,0XF8,0X00,
0XE1,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC3,0X00,0X7F,0X8F,0XFC,0X00,
0XE1,0XFF,0XC7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC7,0X00,0X7C,0X01,0XFC,0X00,
0XE1,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC3,0X00,0X78,0X00,0X3E,0X00,
0XE1,0XFF,0XC7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFE,0X03,0X00,0X78,0X00,0X3E,0X00,
0XE1,0XFF,0XC7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XF0,0X01,0X00,0X78,0X00,0X1F,0X00,
0XE1,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XC0,0X00,0X00,0X78,0X00,0X0F,0X00,
0XE1,0XFF,0XC7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XE0,0X00,0X00,0X78,0X00,0X0F,0X00,
0XE1,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XE0,0XC0,0X00,0X78,0X00,0X0F,0X00,
0XE1,0XFF,0XC7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC6,0X00,0X7C,0X00,0X0F,0X00,
0XE1,0XFF,0XC7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC7,0X00,0X3C,0X00,0X0F,0X00,
0XE1,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC7,0X00,0X3F,0X00,0X0F,0X00,
0XE1,0XFF,0XE3,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC7,0X00,0X3F,0X80,0X1F,0X00,
0XE1,0XFF,0XE7,0XFF,0XFF,0XFF,0XFF,0X00,0X01,0XFF,0XC7,0X00,0X0F,0X80,0X7E,0X00,
0XE1,0XFF,0XF3,0XFF,0XFF,0XFF,0XFF,0X00,0X03,0XFF,0XC7,0X00,0X0F,0X80,0X7E,0X00,
0XE1,0XFF,0XF3,0XFF,0XFF,0XFF,0XFF,0X00,0X03,0XFF,0XC7,0X00,0X03,0X80,0X7C,0X00,
0XF1,0XFF,0XF9,0XFF,0XFF,0XFF,0XFF,0X00,0X03,0XFE,0X87,0X00,0X00,0X00,0X78,0X00,
0XF1,0XFF,0XF9,0XFF,0XFF,0XFF,0XFF,0X00,0X03,0XC0,0X07,0X00,0X00,0X00,0X60,0X00,
0XF1,0XFF,0XE0,0XFF,0XFF,0XFF,0XFF,0X00,0X07,0XC0,0X07,0X00,0X00,0X00,0X00,0X00,
0XF1,0XFF,0XC0,0XFF,0XFF,0XFF,0XFF,0X80,0X07,0XC0,0X00,0X00,0X3F,0X00,0X00,0X00,
0XF9,0XFF,0X00,0X7F,0XFF,0XFF,0XFF,0X80,0X0F,0XE3,0XC0,0X00,0X7F,0X80,0X00,0X00,
0XF8,0XFC,0X00,0X7F,0XFF,0XFF,0XFF,0X80,0X0F,0XFF,0XC0,0X00,0X7F,0XC4,0X00,0X00,
0XF8,0XF0,0X00,0X3F,0XFF,0XFF,0XFF,0X80,0X0F,0XFF,0X8E,0X00,0X7F,0XC7,0X00,0X00,
0XF8,0XF0,0X00,0X1F,0XFF,0XFF,0XFF,0X80,0X1F,0XFF,0X8F,0X00,0X79,0XC7,0X80,0X00,
0XF8,0XF8,0X00,0X1F,0XFF,0XFF,0XFF,0XC0,0X1F,0XFF,0X8F,0X00,0X71,0XC7,0X80,0X00,
0XF8,0X78,0X00,0X0F,0XFF,0XFF,0XFF,0XC0,0X3F,0XFF,0X9F,0X00,0X70,0XE7,0XC0,0X00,
0XFC,0XF8,0X00,0X07,0XFF,0XFF,0XFF,0XC0,0X3F,0XFF,0X1F,0X00,0X70,0XE3,0XC0,0X00,
0XFC,0X7C,0X00,0X07,0XFF,0XFF,0XFF,0XE0,0X7F,0XFF,0X1F,0X00,0X38,0XE3,0XC0,0X00,
0XFC,0X7C,0X00,0X03,0XFF,0XFF,0XFF,0XE0,0XFF,0XFF,0X3F,0X00,0X3C,0XE3,0XC0,0X00,
0XFE,0X7C,0X00,0X01,0XFF,0XFF,0XFF,0XE0,0XFF,0XFE,0X3F,0X00,0X7E,0XE3,0XC0,0X00,
0XFE,0X3C,0X00,0X00,0XFF,0XFF,0XFF,0XE1,0XFF,0XFE,0X7F,0X00,0X7F,0XFF,0XC0,0X00,
0XFE,0X3E,0X00,0X00,0X7F,0XFF,0XFF,0XF1,0XFF,0XFC,0X7F,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0X3E,0X00,0X00,0X3F,0XFF,0XFF,0XF8,0XFF,0XFC,0XFF,0X00,0X7F,0XFF,0X80,0X00,
0XFF,0X1F,0X00,0X00,0X3F,0XFF,0XFF,0XF8,0XFF,0XFC,0XFF,0X00,0X03,0XFF,0X80,0X00,
0XFF,0X1F,0X00,0X00,0X0F,0XFF,0XFF,0XF8,0XFF,0XF8,0XFF,0X00,0X00,0X1E,0X00,0X00,
0XFF,0X9F,0X00,0X00,0X0F,0XFF,0XFF,0XFC,0X7F,0XF9,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0X8F,0X80,0X00,0X20,0X7F,0XFF,0XFC,0X7F,0XF1,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XCF,0X80,0X00,0X20,0X07,0XFF,0XFC,0X7F,0XE3,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XC7,0XC0,0X00,0X67,0X00,0XFF,0XFE,0X3F,0XE7,0XFF,0X00,0X7E,0X03,0XC0,0X00,
0XFF,0XE7,0XC0,0X00,0X67,0XE0,0X0F,0XFF,0X3F,0XC7,0XFF,0X00,0X7F,0XF3,0XC0,0X00,
0XFF,0XE3,0XC0,0X00,0X67,0XE0,0X00,0XFF,0X1F,0XCF,0XFF,0X00,0X7F,0XFF,0XC0,0X00,
0XFF,0XF3,0XE0,0X00,0XE7,0XE0,0X00,0X1F,0X9F,0X8F,0XFF,0X00,0X7F,0XFF,0XF8,0X00,
0XFF,0XF3,0XF0,0X00,0XE7,0XE0,0X00,0X03,0XCE,0X9F,0XFF,0X00,0X07,0XFF,0XFE,0X00,
0XFF,0XF9,0XF0,0X01,0XE7,0XE0,0X00,0X00,0X40,0X1F,0XFF,0X00,0X00,0XFF,0XFF,0X00,
0XFF,0XF8,0XF0,0X01,0XE7,0XF0,0X00,0X70,0X00,0X3F,0XFF,0X00,0X00,0X03,0XFF,0X00,
0XFF,0XFC,0XF8,0X01,0XE7,0XF0,0X00,0X7E,0X01,0XFF,0XFF,0X00,0X00,0X03,0XFF,0X00,
0XFF,0XFC,0X7C,0X03,0XC3,0XF0,0X00,0X3F,0X0F,0XFF,0XFF,0X00,0X00,0X03,0XC7,0X00,
0XFF,0XFE,0X7C,0X03,0XC7,0XF0,0X00,0X3F,0X8F,0XFF,0XFF,0X00,0X00,0X03,0XC7,0X00,
0XFF,0XFF,0X3E,0X07,0X83,0XF8,0X00,0X3F,0X8F,0XFF,0XFF,0X00,0X03,0XC0,0X0F,0X00,
0XFF,0XFF,0X1E,0X1F,0X93,0XF8,0X00,0X3F,0XC7,0XFF,0XFF,0X00,0X0F,0XF8,0X0F,0X00,
0XFF,0XFF,0X9F,0XFF,0X39,0XFE,0X00,0X3F,0XC7,0XFF,0XFF,0X00,0X3F,0XFE,0X00,0X00,
0XFF,0XFF,0XCF,0XFF,0X39,0XFF,0X80,0X1F,0XE3,0XFF,0XFF,0X00,0X3F,0XFF,0X00,0X00,
0XFF,0XFF,0XE7,0XFE,0X7C,0XFF,0XE8,0X1F,0XE3,0XFF,0XFF,0X00,0X7F,0XFF,0X80,0X00,
0XFF,0XFF,0XE1,0XFC,0X7C,0X7F,0XFF,0X0F,0XE3,0XFF,0XFF,0X00,0X78,0XE7,0X80,0X00,
0XFF,0XFF,0XF0,0X14,0XFE,0X7F,0XFF,0XFF,0XE3,0XFF,0XFF,0X00,0X70,0XE7,0XC0,0X00,
0XFF,0XFF,0XFC,0X01,0XFF,0X3F,0XFF,0XFF,0XC3,0XFF,0XFF,0X00,0X70,0XE3,0XC0,0X00,
0XFF,0XFF,0XFF,0XEB,0XFF,0X9E,0X9F,0XFF,0X8F,0XFF,0XFF,0X00,0X70,0XE3,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0X87,0X01,0X7F,0X0F,0XFF,0XFF,0X00,0X70,0XE3,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0XF0,0X3E,0X3F,0XFF,0XFF,0X00,0X78,0XE3,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X3E,0X7C,0X7F,0XFF,0XFF,0X00,0X7C,0XE7,0XC0,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X07,0XF0,0XFF,0XFF,0XFF,0X00,0X3C,0XFF,0X80,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X71,0XFF,0XFF,0XFF,0X00,0X3C,0XFF,0X80,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X03,0XFF,0XFF,0XFF,0X00,0X0C,0XFF,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X0F,0XFF,0XFF,0XFF,0X00,0X00,0XFE,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X00,0X00,0X00,0X00,0X00,
};




const unsigned char code  gImage_1[4000] = { 
/*  0X01,0X01,0XFA,0X00,0X7A,0X00, */
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7E,0XFF,0X77,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0XFF,0X4F,0XFF,0XFF,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBE,0XF8,0X00,0X7F,0XFF,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XFF,0X6F,0XFF,0XFF,0X67,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XFF,0XBD,0XFF,0XFF,0XF8,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XFD,0XB3,0XFF,0XFF,0X67,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7E,0XFD,0XBF,0X7F,0XFF,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X80,0XFD,0X80,0X7F,0XFF,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFE,0XFD,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFD,0XB7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFC,0XFF,0XB9,0XFF,0XFF,0XFC,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFC,0XFF,0XFF,0XFF,0XFF,0XFC,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0X9F,0X9F,0XFF,0XFF,0XFE,0X00,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFE,0X1F,0X9F,0XFF,0XFF,0XFC,0XEE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XF0,0XDF,0X9F,0XFF,0XFF,0XFA,0XEE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X87,0XDF,0X9F,0XFF,0XFF,0XFE,0XEE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFC,0X37,0XFF,0X9F,0XFF,0XFF,0XFE,0X00,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XE1,0XF7,0XFF,0X9F,0XFF,0XFF,0XFF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XC7,0XF7,0XFF,0X9F,0XFF,0XFF,0XFF,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XC0,0XF7,0XFF,0X9F,0XFF,0XFF,0XF8,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XF8,0X17,0XFF,0X9F,0XFF,0XFF,0XFE,0XE7,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X03,0XDF,0X9F,0XFF,0XFF,0XFE,0XFF,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0X1F,0X9F,0XFF,0XFF,0XFE,0X00,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XF8,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0X1F,0X9F,0XFE,0X00,0X3E,0XFF,0XFF,0XFE,0XDB,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFE,0XDB,0X7C,0X80,0X7F,0XFE,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFE,0XDB,0X7A,0XAB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7E,0XAB,0X7F,0XFE,0XC0,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFE,0XDB,0X7C,0X80,0X7F,0XFC,0X5B,0X7F,0XFF,0XFF,0XC0,
0XFF,0XF7,0XBF,0XDF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFE,0XDB,0X7F,0XFF,0XFF,0XC0,
0XFF,0XE3,0X00,0X1F,0X9F,0XFE,0XDB,0X78,0X60,0XFF,0XFE,0XC0,0X7F,0XFF,0XFF,0XC0,
0XFF,0XE7,0X00,0X1F,0X9F,0XFE,0XDB,0X7E,0XBD,0X7F,0XFE,0XDB,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFE,0X00,0X3D,0XBB,0X7F,0XFC,0X5B,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFB,0XB7,0X7F,0XFE,0XC0,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0X3C,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0X7F,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XA7,0XFF,0X7F,0X7F,0XFF,0XBE,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFC,0X00,0X3F,0X7E,0XFF,0XFF,0XED,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XB7,0XFF,0X7D,0XFF,0XFF,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XDE,0XFF,0X73,0XFF,0XFF,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFE,0XD9,0XF8,0X0F,0XFF,0XFC,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XFF,0X9F,0XFE,0XDF,0XBF,0X7F,0XFF,0XFF,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFE,0XC0,0X3F,0X7F,0X7F,0XFD,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFE,0XDF,0XFF,0X7F,0X7F,0XFE,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFE,0XDB,0XFF,0X7F,0X7F,0XFF,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X1F,0X9F,0XFF,0XDC,0XFF,0X00,0XFF,0XFF,0X7F,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFF,0XF2,0XFF,0XFF,0XFF,0XFF,0XF2,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFF,0XF1,0XFF,0XFF,0XFF,0XFF,0XF1,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X6F,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X00,0X3F,0XFF,0XFF,0XFF,0X72,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0X7D,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0X72,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0X0F,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XB7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XB9,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XBF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X00,0X3F,0XFF,0XFF,0XFC,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X3F,0XFF,0XFF,0XFF,0X7F,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X77,0X7F,0XFF,0XFF,0XFF,0XBE,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X77,0X7F,0XFF,0XFF,0XFF,0XED,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X77,0X7F,0XFF,0XFF,0XFF,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X3F,0XFF,0XFF,0XFF,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0XFF,0XFF,0XFF,0XFC,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBF,0XFF,0XFF,0XFF,0XFF,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X6F,0XFF,0XFF,0XFF,0XFD,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X73,0XBF,0XFF,0XFF,0XFE,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XBF,0XFF,0XFF,0XFF,0X6D,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X7F,0XFF,0XFF,0XFF,0X7F,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X92,0XFF,0XFF,0XFF,0XFF,0X92,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X91,0XFF,0XFF,0XFF,0XFF,0X91,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFC,0X30,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X00,0X3F,0XFF,0XFF,0XFF,0X55,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X55,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XC0,0X3F,0XFF,0XFF,0XFE,0XD5,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X5B,0X7F,0XFF,0XFF,0XFE,0XD5,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFE,0XD5,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XC0,0X7F,0XFF,0XFF,0XFD,0XD5,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFD,0XD5,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X5B,0X7F,0XFF,0XFF,0XFF,0X10,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XC0,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0X7F,0XFF,0XFF,0XFF,0X7B,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBE,0XFF,0XFF,0XFF,0XFF,0X77,0XFF,0XFD,0XBF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XED,0XFF,0XFF,0XFF,0XFF,0X60,0X3F,0XFB,0XDF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0XFF,0XFF,0XFF,0XFF,0X1F,0XFF,0XFB,0XDF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X3F,0XFF,0XFF,0XFC,0X7F,0XBF,0XF7,0XEF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X6D,0XBF,0XFF,0XFF,0XFF,0X7B,0XBF,0XE7,0XEF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6D,0XBF,0XFF,0XFF,0XFF,0X7B,0XBF,0XEF,0XF7,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X00,0X3F,0XFF,0XFF,0XFF,0X40,0X3F,0XC0,0X03,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X6D,0XBF,0XFF,0XFF,0XFF,0X7B,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6D,0XBF,0XFF,0XFF,0XFF,0X7B,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XBF,0XFF,0XFF,0XFF,0X7F,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X03,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF2,0XFF,0XFF,0XFF,0XFF,0XF2,0XFF,0XF0,0X0F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF1,0XFF,0XFF,0XFF,0XFF,0XF1,0XFF,0XF0,0X0F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0XBF,0XFF,0XFF,0XFE,0XDB,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X72,0X7F,0XFF,0XFF,0XFE,0X9B,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7D,0XFF,0XFF,0XFF,0XFE,0X40,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X72,0XFF,0XFF,0XFF,0XFE,0XDA,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X0F,0X3F,0XFF,0XFF,0XFE,0X9A,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XEF,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB7,0XFF,0XFF,0XFF,0XFF,0X92,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB9,0XBF,0XFF,0XFF,0XFC,0X3D,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBF,0XBF,0XFF,0XFF,0XFF,0XBA,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X00,0X3F,0XFF,0XFF,0XFF,0X87,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBF,0XFF,0XFF,0XFF,0XFF,0XBF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0X7F,0XFF,0XFF,0XFF,0XBF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBE,0XFF,0XFF,0XFF,0XFF,0XBF,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XED,0XFF,0XFF,0XFF,0XFF,0XBE,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0XFF,0XFF,0XFF,0XFF,0XB9,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X3F,0XFF,0XFF,0XFC,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X6D,0XBF,0XFF,0XFF,0XFF,0XBF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6D,0XBF,0XFF,0XFF,0XFF,0XBF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X00,0X3F,0XFF,0XFF,0XFF,0XBF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X6D,0XBF,0XFF,0XFF,0XFF,0XBF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6D,0XBF,0XFF,0XFF,0XFF,0X80,0X7F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X92,0XFF,0XFF,0XFF,0XFD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X91,0XFF,0XFF,0XFF,0XFD,0XEF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XEF,0XBF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X00,0X3F,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XA7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XA0,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0XEF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6D,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XA1,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0XEE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XF5,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB7,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB6,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB1,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X07,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB7,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB5,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB6,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF7,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF2,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF1,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XEF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X68,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X00,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6F,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X68,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XEF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X81,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X81,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
};
const unsigned char code  gImage_2[4000] = { 
/*0X01,0X01,0XFA,0X00,0X7A,0X00, */
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7E,0XFF,0XFF,0XFF,0XFB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0XFF,0XF7,0XFF,0XBB,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBE,0XFF,0XF1,0XFF,0XD8,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XFF,0XF6,0X7F,0XFF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XFF,0XFF,0X8F,0XFF,0XD7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XFF,0XF6,0X7F,0XC0,0X37,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7E,0XFF,0XF1,0XFF,0XDB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X80,0XFF,0XF7,0XFF,0XDB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFE,0XFF,0XFF,0XFF,0XB8,0X17,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XBB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFC,0XFF,0XFF,0XCF,0XFB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFC,0XFF,0XFF,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0X9F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFB,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFE,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XF0,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X87,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFC,0X37,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XE1,0XF7,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XB7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XC7,0XF7,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XC0,0XF7,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE7,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XF8,0X17,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X03,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0X83,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XF8,0X1F,0X9F,0XFF,0X7F,0XBF,0XFB,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0X1F,0X9F,0XFF,0X7F,0X7F,0XF3,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0X7C,0XFF,0XC8,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0X03,0XFF,0XEA,0XAF,0XFE,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X6F,0XFF,0XEA,0X03,0XFE,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XFE,0X9F,0XFE,0X6F,0XFF,0XC2,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XFE,0X9F,0XFF,0X6F,0XBF,0XEA,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X00,0X9F,0XFF,0X6F,0XBF,0XEA,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X00,0X9F,0XFF,0X6F,0XBF,0XE8,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0X9E,0X9F,0XFF,0X60,0X7F,0XEB,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDE,0X9F,0XFF,0X7F,0XFF,0XFB,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XCF,0X9F,0XFF,0XDF,0X7F,0XFD,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFD,0XEE,0XFF,0XDD,0XF7,0XF7,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X1F,0X1F,0X9F,0XFE,0XF5,0XFF,0XEC,0X0F,0XF7,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X3F,0X9F,0XFF,0XB7,0X7F,0XFF,0XF7,0X80,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0X7F,0X9F,0XFF,0XB6,0X7F,0XFF,0XEB,0XF6,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB1,0X7F,0XE0,0X1B,0XED,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X07,0X7F,0XED,0XFB,0XE5,0X57,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XFE,0X9F,0XFF,0XB7,0X7F,0XED,0XFB,0XA9,0X17,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XFE,0X9F,0XFF,0XB5,0X7F,0XDC,0X0B,0XCC,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X00,0X9F,0XFF,0XB6,0X7F,0XDD,0XFB,0XE9,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X00,0X9F,0XFF,0XF7,0X3F,0XFD,0XFB,0XE5,0X17,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0X9E,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XED,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDE,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XCF,0X9F,0XFF,0XF2,0XFF,0XFF,0X2F,0XBB,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFF,0XF1,0XFF,0XFF,0X1F,0XD8,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X1F,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X3F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XD7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0X7F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X37,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XDB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XDB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XB8,0X17,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XBB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0X77,0X7F,0XF0,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0XDF,0X9F,0XFF,0X74,0XFF,0XFF,0XFF,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0X6F,0XFF,0XC0,0X03,0XBD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0X5C,0X7F,0XFD,0XFF,0XBD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0X3F,0XBF,0XFB,0X03,0XBD,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFC,0X6B,0XBF,0XC7,0X77,0XBD,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X34,0XBF,0XF7,0X77,0X80,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0XFF,0X9F,0XFF,0X5F,0XBF,0XF3,0X07,0XBD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X3F,0X9F,0XFF,0X6F,0X3F,0XF5,0X77,0XBD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0X1F,0X9F,0XFF,0X75,0XFF,0XF7,0X77,0XBD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFF,0X76,0X7F,0XF7,0X03,0XBD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFF,0XFF,0XBF,0XFD,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFE,0X00,0X7F,0XDD,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0X9F,0X9F,0XFE,0XBF,0XFF,0XEC,0X0F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0X3F,0X9F,0XFE,0XBB,0XBF,0XFF,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X3F,0X9F,0XFE,0X09,0XBF,0XFF,0XEB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0XFF,0X9F,0XFE,0XAA,0XBF,0XE0,0X1B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0XAB,0X7F,0XED,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XAB,0X7F,0XED,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFE,0X3F,0X9F,0XFE,0X0A,0XBF,0XDC,0X0B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X8C,0X1F,0X9F,0XFE,0XB9,0XBF,0XDD,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X8C,0XDF,0X9F,0XFE,0XBF,0XBF,0XFD,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3D,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X79,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7B,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7B,0XBF,0X9F,0XFF,0X92,0XFF,0XF9,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3B,0XBF,0X9F,0XFF,0X91,0XFF,0XF9,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X3F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XC0,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XC0,0X3F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0X9F,0X9F,0XFF,0XBA,0XFF,0XFB,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFF,0X3A,0XFF,0XFB,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFC,0X8A,0XFF,0XC0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFE,0XAA,0XFF,0XFB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFE,0XA0,0X3F,0XF6,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0XBF,0X9F,0XFC,0X2F,0XFF,0XF2,0XAB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X8F,0X3F,0X9F,0XFE,0XA0,0X3F,0XD4,0X8B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XAA,0XFF,0XE6,0X37,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X8A,0XFF,0XF4,0XB7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XF7,0XFF,0XDF,0X9F,0XFE,0XBA,0XFF,0XF2,0X8B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XF7,0XFF,0XDF,0X9F,0XFF,0XBA,0XFF,0XF6,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XE0,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XE0,0X00,0X1F,0X9F,0XFF,0XDF,0XBF,0XEE,0XF7,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XDF,0XDF,0X9F,0XFD,0XDF,0X7F,0XF7,0X6F,0XFF,0XFF,0XFF,0XFD,0XBF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFE,0XC0,0XFF,0XFE,0XFF,0XFF,0XFF,0XFF,0XFB,0XDF,0XC0,
0XFF,0XFF,0XBF,0XFF,0X9F,0XFF,0XFF,0X7F,0XFD,0X83,0XFF,0XFF,0XFF,0XFB,0XDF,0XC0,
0XFF,0XFF,0X7F,0XFF,0X9F,0XFF,0XFE,0XBF,0XFA,0XB7,0XFF,0XFF,0XFF,0XF7,0XEF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFE,0X01,0XBF,0XF6,0XB7,0XFF,0XFF,0XFF,0XE7,0XEF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFE,0XDF,0XBF,0XCE,0XB7,0XFF,0XFF,0XFF,0XEF,0XF7,0XC0,
0XFF,0XFF,0X80,0X1F,0X9F,0XFE,0XDF,0XBF,0XF6,0XB7,0XFF,0XFF,0XFF,0XC0,0X03,0XC0,
0XFF,0XFF,0XC0,0X1F,0X9F,0XFD,0XC0,0XBF,0XFA,0XB7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFD,0XDF,0XBF,0XFD,0X83,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XDF,0XBF,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,0X03,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF2,0XFF,0XFF,0X2F,0XFF,0XFF,0XFF,0XF0,0X0F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF1,0XFF,0XFF,0X1F,0XFF,0XFF,0XFF,0XF0,0X0F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X1F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XF7,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XBF,0XF7,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X00,0X3F,0XF6,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB7,0XFF,0XF5,0X77,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6B,0XBF,0XD7,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X2A,0XBF,0XE7,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X48,0XBF,0XF7,0XAF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X63,0X7F,0XF5,0X77,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X4B,0X7F,0XF6,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X28,0XBF,0XF7,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6B,0XBF,0XF7,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0XBF,0XFD,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0XDF,0X7F,0XDD,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XC0,0XFF,0XEC,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0X7F,0XFF,0XEB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFE,0XBF,0XFA,0XDB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X01,0XBF,0XE6,0XB7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDF,0XBF,0XFD,0XEF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XDF,0XBF,0XC3,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0XC0,0XBF,0XFD,0XEF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0XDF,0XBF,0XF5,0XD7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0XBF,0XEE,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X92,0XFF,0XF9,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X91,0XFF,0XF9,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XFF,0XF6,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XBF,0XF7,0X27,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X00,0X3F,0XF7,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB7,0XFF,0XF7,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6B,0XBF,0XF0,0XF3,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X2A,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X48,0XBF,0XFB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X63,0X7F,0XFB,0X9B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X4B,0X7F,0XFB,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X28,0XBF,0XC0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6B,0XBF,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XEF,0X7F,0XFE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X76,0XFF,0XFD,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XEF,0XFF,0XF0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XD8,0X3F,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XAB,0X7F,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6B,0X7F,0XFB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0XEB,0X7F,0XFB,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6B,0X7F,0XFB,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XAB,0X7F,0XFB,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XD8,0X3F,0XC0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XEF,0XFF,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF2,0XFF,0XFF,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XF1,0XFF,0XFF,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XFB,0XBF,0XFF,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X8B,0XBF,0XFC,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XAA,0XBF,0XC3,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XA8,0XBF,0XF7,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X03,0X7F,0XF7,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XAB,0X7F,0XF0,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X0B,0X7F,0XFF,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XAA,0XBF,0XC0,0X0B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XA9,0XBF,0XFB,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X8B,0XBF,0XFD,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XFB,0XFF,0XFE,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7E,0XFF,0XEE,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X5E,0XFF,0XE0,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6D,0XFF,0XEE,0XEF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7B,0XFF,0XFF,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X77,0XBF,0XC0,0X5B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X00,0X3F,0XDB,0X5B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X4F,0XFF,0XDB,0X5B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X73,0XFF,0XC0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X6D,0XFF,0XDB,0X5B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X5E,0XFF,0XDB,0X5B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0X7F,0XC0,0X5B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF9,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF9,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
};
const unsigned char code  gImage_3[4000] = { 	
/* 0X01,0X01,0XFA,0X00,0X7A,0X00, */
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XB9,0XFF,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X76,0XFF,0XF1,0XFF,0XF2,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6E,0XFF,0XF6,0X7F,0XF2,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6E,0XFF,0XFF,0X8F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X6D,0XFF,0XF6,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X80,0XFF,0XF1,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFE,0XFF,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XC3,0XFF,0XFF,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XBD,0XFF,0XFF,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0X9F,0X9F,0XFF,0X7E,0XFF,0XFF,0XFF,0XC0,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFE,0X1F,0X9F,0XFF,0X7E,0XFF,0XFF,0XFF,0XDF,0XBF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XF0,0XDF,0X9F,0XFF,0X7E,0XFF,0XFF,0XFF,0XC0,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X87,0XDF,0X9F,0XF7,0XBD,0XFF,0XFF,0XFF,0XFF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFC,0X37,0XFF,0X9F,0XF0,0X00,0XFF,0XFF,0XFF,0XDF,0XCF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XE1,0XF7,0XFF,0X9F,0XFF,0XFE,0XFF,0XFF,0XFF,0XC0,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XC7,0XF7,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XC0,0XF7,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0XAF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XF8,0X17,0XFF,0X9F,0XFF,0XFF,0X3F,0XFF,0XFF,0XD9,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X03,0XDF,0X9F,0XFF,0XFF,0XBF,0XFF,0XFF,0XC5,0XAF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0X1F,0X9F,0XFF,0X7F,0XBF,0XFF,0XFF,0XFC,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XF8,0X1F,0X9F,0XF3,0X7F,0XBF,0XDD,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0X1F,0X9F,0XF3,0X00,0X7F,0XEC,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFB,0XFB,0XD8,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFF,0XEA,0XAB,0XDB,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XEA,0XDB,0XDB,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFC,0XFF,0XEA,0XAB,0XDB,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFC,0XFF,0XC0,0X0B,0XC3,0X0F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XEA,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XEA,0XDB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0XDF,0X9F,0XFF,0XFF,0XFF,0XE0,0XAB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFB,0XFB,0X80,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XBB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XC0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFB,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XF4,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XF5,0X5F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XF5,0X5F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X9F,0XDF,0X9F,0XFF,0XFF,0XFF,0XC0,0X07,0XF8,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XF5,0X5F,0XE7,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0XFF,0XFF,0XD5,0X5B,0XDF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0XFF,0XFF,0XE4,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X00,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X6B,0X7F,0XFF,0XFF,0XDF,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE0,0XFF,0X9F,0XFC,0X1B,0X7F,0XF9,0X2F,0XDF,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XC0,0X3F,0X9F,0XFD,0X6B,0X7F,0XF9,0X1F,0X81,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X97,0X3F,0X9F,0XFD,0X00,0X3F,0XFF,0XFF,0XD5,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XB7,0X9F,0X9F,0XFF,0XFD,0XFF,0XFF,0XFF,0XD5,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X77,0XDF,0X9F,0XFC,0X12,0XBF,0XFF,0XFF,0XD4,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X77,0XDF,0X9F,0XFD,0X5A,0XBF,0XFF,0XFF,0XD5,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X37,0XDF,0X9F,0XFD,0X40,0X3F,0XFF,0XFF,0XD5,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X97,0XDF,0X9F,0XFD,0X5A,0XBF,0XFF,0XFF,0X81,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X87,0XBF,0X9F,0XFC,0X1A,0XBF,0XFF,0XFF,0XDF,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XE7,0X7F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFE,0XFF,0X9F,0XFE,0X00,0X3F,0XFB,0XBB,0XFF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X86,0X1F,0X9F,0XFE,0XDB,0X7F,0XC0,0X03,0XFF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X27,0XBF,0X9F,0XFE,0XDB,0X7F,0XFB,0X7F,0XFF,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X73,0X9F,0X9F,0XFE,0XDB,0X7F,0XFF,0XFF,0XFF,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X73,0XDF,0X9F,0XFE,0XDB,0X7F,0XF0,0X03,0XFC,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X73,0XDF,0X9F,0XFE,0XDB,0X7F,0XF7,0XF7,0X83,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X39,0XDF,0X9F,0XFE,0XDB,0X7F,0XF7,0XF7,0XFC,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X19,0X9F,0X9F,0XFE,0XDB,0X7F,0XF7,0XF7,0XFF,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X8C,0X3F,0X9F,0XFE,0X00,0X3F,0XF7,0XF7,0XFF,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFE,0X7F,0X9F,0XFF,0XFF,0XFF,0XF0,0X03,0XFF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X3F,0XE1,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XFF,0X9F,0XFE,0X77,0X7F,0XED,0X03,0XE0,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XFF,0X9F,0XFD,0X77,0X7F,0XE5,0X57,0XCE,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFC,0X00,0X3F,0X9F,0XFF,0X77,0X7F,0XDB,0X57,0XAE,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XF0,0X00,0X1F,0X9F,0XFF,0X00,0X3F,0XDD,0X57,0XEE,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0X9F,0X9F,0XFF,0XDF,0XFF,0XFF,0X07,0XE0,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFF,0XBF,0XFF,0XED,0X57,0XFB,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFC,0X6F,0XFF,0XE3,0X57,0XF7,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XBF,0X9F,0XFF,0X73,0XBF,0XEF,0X57,0X8D,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XBF,0XED,0X03,0XEE,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0X00,0X7F,0XE1,0XFF,0XEF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XF7,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X0F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XE3,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XE7,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0X92,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0X91,0XFF,0XFF,0XFF,0XDF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE7,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFC,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XF3,0XCF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFF,0XFF,0XFF,0XEF,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XDF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XBF,0XDF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X7F,0XDF,0X9F,0XFE,0XC3,0XFF,0XF0,0X07,0XDD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X3F,0XDF,0X9F,0XFE,0XDB,0XBF,0XE5,0X5F,0XEE,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X00,0X1F,0X9F,0XFE,0XDB,0XBF,0XD6,0X6B,0XFF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0X1F,0X9F,0XFE,0XDB,0XBF,0XF0,0X03,0XF7,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFE,0X18,0X7F,0XFD,0XFF,0XF7,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XDF,0X9F,0XFF,0XFF,0XFF,0XE3,0X03,0XB7,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XEF,0X77,0XD0,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XF1,0X9F,0XFF,0XFF,0XFF,0XEF,0X77,0XF7,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XC2,0X21,0X9F,0XFC,0X00,0X3F,0XE3,0X03,0XF7,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0X80,0XAC,0X9F,0XFF,0XFF,0XFF,0XFD,0XFF,0XF7,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XB9,0X9E,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF7,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0X7C,0X9E,0X9F,0XFF,0XFF,0XBF,0XFF,0XFB,0XFF,0XFF,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0X7C,0X9E,0X9F,0XFF,0XFF,0X7F,0XE0,0X77,0XF7,0XF7,0XFF,0XFD,0XBF,0XC0,
0XFF,0XFF,0X7C,0XDE,0X9F,0XFF,0XFE,0XFF,0XEF,0X6F,0XD7,0XCF,0XFF,0XFB,0XDF,0XC0,
0XFF,0XFF,0XB9,0XDE,0X9F,0XFF,0XF9,0XFF,0XEF,0X7F,0XD0,0X7F,0XFF,0XFB,0XDF,0XC0,
0XFF,0XFF,0X81,0XCE,0X9F,0XFF,0XE7,0XFF,0XEF,0X7F,0XC5,0X4F,0XFF,0XF7,0XEF,0XC0,
0XFF,0XFF,0X83,0XCD,0X9F,0XFC,0X1F,0XFF,0XEF,0X7F,0XD5,0X77,0XFF,0XE7,0XEF,0XC0,
0XFF,0XFF,0X3F,0XE1,0X9F,0XFF,0XE7,0XFF,0XEF,0X7F,0X95,0X37,0XFF,0XEF,0XF7,0XC0,
0XFF,0XFF,0XBF,0XF3,0X9F,0XFF,0XF9,0XFF,0XEF,0X7F,0XD5,0X57,0XFF,0XC0,0X03,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFE,0XFF,0XEF,0X6F,0XC5,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0X7F,0XE0,0X77,0XD0,0X67,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XBF,0XFF,0XFB,0XD7,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF7,0XE7,0XFF,0XC0,0X03,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XEF,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X76,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XBF,0XEF,0XF7,0XFF,0XFF,0XFF,0XF0,0X0F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XBF,0XF3,0XCF,0XFF,0XFF,0XFF,0XF0,0X0F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XBF,0XFC,0X3F,0XFF,0XFF,0XFF,0XF8,0X1F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0XBB,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X80,0X3F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X3F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XBF,0XFF,0XFF,0XF8,0X7F,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XBF,0XFF,0XFF,0XE7,0X9F,0XFF,0XFE,0X7F,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBB,0XBF,0XFF,0XFF,0XDF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XBE,0X7F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X83,0XFF,0XF9,0X2F,0XFE,0XBF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X2A,0X7F,0XF9,0X1F,0XFD,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XAB,0XBF,0XFF,0XFF,0XFD,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0XA9,0XBF,0XFF,0XFF,0XFE,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XAA,0XBF,0XFF,0XFF,0XFF,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X2B,0XBF,0XFF,0XFF,0XFD,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X83,0X3F,0XFF,0XFF,0XFC,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0XBE,0XFF,0XFF,0XFF,0XFE,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBF,0X3F,0XFF,0XFF,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X3F,0XFB,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFE,0X77,0X7F,0XFB,0XBB,0XFD,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFD,0X77,0X7F,0XC0,0X03,0XFC,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X77,0X7F,0XFB,0X7F,0XFE,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X3F,0XF0,0X0F,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XDF,0XFF,0XEF,0XDF,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XBF,0XFF,0XDF,0XBF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFC,0X6F,0XFF,0XF0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X73,0XBF,0XF7,0XFF,0XFE,0X3F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X7F,0XBF,0XF7,0XEF,0XFD,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0X00,0X7F,0XF0,0X0F,0XFD,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFE,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF9,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XE5,0X07,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF5,0X7F,0XFC,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XC0,0X03,0XFD,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF5,0X77,0XFD,0X5F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF5,0X07,0XFD,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFD,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF0,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFB,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFB,0XF0,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XC0,0X03,0XFD,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF9,0X2F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF9,0X1F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XCE,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XAE,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XEE,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XE0,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XEF,0XFB,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0X1F,0XF7,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0X8D,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFC,0X07,0XEE,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XEF,0XFB,0XEF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF7,0XFB,0XE0,0X0F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF9,0XFB,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFB,0XDD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XE3,0XDD,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFE,0XFF,0XC0,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0X1F,0XDD,0XDF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFB,0XC0,0X6F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XE0,0X07,0XDF,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XED,0XBB,0XD0,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XE0,0X03,0XDF,0X8F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFB,0XC0,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF0,0X07,0XFF,0XE7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF7,0X7B,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XD7,0X7B,0XEF,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XE4,0X03,0XEE,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF7,0X7B,0XEC,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF7,0X7B,0XE3,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0X8F,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XDB,0XEF,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFD,0XB7,0XEF,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF0,0X0F,0XE8,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF7,0XFF,0XEF,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF5,0X03,0XEF,0X77,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XD5,0X6F,0XEF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XE5,0X5F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF4,0X3F,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF5,0X5F,0XFB,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF5,0X6B,0XE5,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF5,0X03,0X9D,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFC,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XE3,0XF7,0XFD,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XEF,0XFD,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0X9B,0X9D,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF8,0X7B,0XE4,0X0F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XC3,0X37,0XFB,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0X57,0XFD,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0X6F,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XDB,0X57,0XBB,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XEB,0X37,0XD8,0X07,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XFB,0XFF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XFB,0XF7,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XD4,0X1F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFE,0XFF,0XD5,0XBF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFD,0XFF,0XD5,0XBF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF0,0X03,0XD5,0XB7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XCF,0XFF,0XD4,0X37,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFB,0XFF,0XDF,0XF7,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XC7,0XFF,0XC0,0X0F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF0,0X03,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF6,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF6,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF6,0XDF,0XDF,0XEF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XF7,0XDF,0XE7,0X9F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XF8,0X7F,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0X9F,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC0,
};




//  DESAY xxxxxxxxxxxxxxxxxxxxxx

void DELAY_100nS(int delaytime)   						// 30us 
{
	int i,j;
	
	for(i=0;i<delaytime;i++)
		for(j=0;j<1;j++);
}

void DELAY_mS(int delaytime)    						// 1ms
{
	int i,j;
	
	for(i=0;i<delaytime;i++)
		for(j=0;j<200;j++);
}

void DELAY_S(int delaytime)     						// 1s
{
	int i,j,k;
	
	for(i=0;i<delaytime;i++)
		for(j=0;j<1000;j++)
			for(k=0;k<200;k++);

				for(;log==1;);
}





// WRITE COMMAND  xxxxxxxxxxxxxxxxxxx
void EPD_W21_WriteCMD(unsigned char INIT_COM)
{
  	unsigned char TEMPCOM;
  	unsigned char scnt;

  	TEMPCOM=INIT_COM;
    	SCLK_H;  
 	nDC_L;
  	nCS_H;
  	nCS_L;
  	for(scnt=0;scnt<8;scnt++)
  	{ 	SCLK_L;  
    	if(TEMPCOM&0x80)
     	 	SDA_H;
    	else
      		SDA_L;
    
    	SCLK_H;  
    	TEMPCOM=TEMPCOM<<1;
  	}
  	nCS_H;  
}

// WRITE DATA  xxxxxxxxxxxxxxxxxxxxx
void EPD_W21_WriteDATA(unsigned char INIT_DATA)
{
  	unsigned char TEMPCOM;
  	unsigned char scnt;

  	TEMPCOM=INIT_DATA;
    	SCLK_H;  
 	nDC_H;
  	nCS_H;
  	nCS_L;
  	for(scnt=0;scnt<8;scnt++)
  	{    	SCLK_L;  
    	if(TEMPCOM&0x80)
     	 	SDA_H;
    	else
      		SDA_L;
 
    	SCLK_H;  
    	TEMPCOM=TEMPCOM<<1;
  	}
  	nCS_H;  
}




//*******************EPD_init(void)***************************//	
//Initialize settings. You must re-initialize settings after resetting.
//******************************************************//				
void EPD_init(void)
{
	
    LUT_Flag=0,Border_Flag=0;

		EPD_W21_WriteCMD(0x00);       
		EPD_W21_WriteDATA(0xFF);//You can change the scanning direction, FF -> FB F3 F7 to rotate and flip left and right and up and down

		
		EPD_W21_WriteCMD(0x01); 
		EPD_W21_WriteDATA(0x03);    
		EPD_W21_WriteDATA(0x00);    
		EPD_W21_WriteDATA(0x3F);    
		EPD_W21_WriteDATA(0x3F);    
		EPD_W21_WriteDATA(0x03);    

		EPD_W21_WriteCMD(0x03);       
		EPD_W21_WriteDATA(0x00);    

		EPD_W21_WriteCMD(0x06);       
		EPD_W21_WriteDATA(0x27);    
		EPD_W21_WriteDATA(0x27);    
		EPD_W21_WriteDATA(0x2F);    

		EPD_W21_WriteCMD(0x30);       
		EPD_W21_WriteDATA(0x09);   

		EPD_W21_WriteCMD(0x60);       
		EPD_W21_WriteDATA (0x22);   

		EPD_W21_WriteCMD(0x82);        // vcom
		EPD_W21_WriteDATA(0x00);      // 

		EPD_W21_WriteCMD(0xE3);        
		EPD_W21_WriteDATA(0x00);    

		EPD_W21_WriteCMD(0x41);        
		EPD_W21_WriteDATA(0x00);   
		
		EPD_W21_WriteCMD(0x61);    
		EPD_W21_WriteDATA(0x80);     
		EPD_W21_WriteDATA(0x00);   
		EPD_W21_WriteDATA(0xFA);  
  
		EPD_W21_WriteCMD(0x65);        
		EPD_W21_WriteDATA(0x00);    
		EPD_W21_WriteDATA(0x00);    
		EPD_W21_WriteDATA(0x00);    

		EPD_W21_WriteCMD(0X50);      
		EPD_W21_WriteDATA(0xB7); 
}



//****************EPD_refresh(void)************************//	
//Screen refresh command
//******************************************************//
void EPD_refresh(void)
{
	Border_Flag=1;	
	EPD_W21_WriteCMD(0x17);			
  EPD_W21_WriteDATA(0xA5);
	lcd_chkstatus();
}	


//***************EPD_sleep(void)************************//	
//Enter sleep
//After exiting sleep, you need to re-initialize the settings. Use GC to refresh the first screen, and then use DU to refresh the screen.
//******************************************************//
void EPD_sleep(void)
{
		EPD_W21_WriteCMD(0X07); //deep sleep
		EPD_W21_WriteDATA(0xA5);
}



//***************lut_GC(void)************************//	
//Call GC waveform
//***************************************************//
void lut_GC(void)
{
	unsigned int count;	 
	
		EPD_W21_WriteCMD(0x20);							//vcom
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R20_GC[count]);}
		
	  EPD_W21_WriteCMD(0x21);							//red not use
	  for(count=0;count<56;count++)
		  {EPD_W21_WriteDATA(lut_R21_GC[count]);}

		EPD_W21_WriteCMD(0x24);							//bb b
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R24_GC[count]);}			
			
 if (LUT_Flag==0)	
 {

	  EPD_W21_WriteCMD(0x22);							//bw r
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R22_GC[count]);}

		EPD_W21_WriteCMD(0x23);							//wb w
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R23_GC[count]);}
   LUT_Flag=1;
 }
 else
 {
	 
	  EPD_W21_WriteCMD(0x22);							//bw r
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R23_GC[count]);}

		EPD_W21_WriteCMD(0x23);							//wb w
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R22_GC[count]);}
   LUT_Flag=0;
	}
	 			         
}


//***************lut_DU(void)************************//	
//Call DU waveform
//***************************************************//
void lut_DU(void)
{
	unsigned int count;	 
	
		EPD_W21_WriteCMD(0x20);							//vcom
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R20_DU[count]);}
		
	  EPD_W21_WriteCMD(0x21);							//red not use
	  for(count=0;count<56;count++)
		  {EPD_W21_WriteDATA(lut_R21_DU[count]);}

		EPD_W21_WriteCMD(0x24);							//bb b
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R24_DU[count]);}			
			
 if (LUT_Flag==0)	
 {
 
	  EPD_W21_WriteCMD(0x22);							//bw r
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R22_DU[count]);}

		EPD_W21_WriteCMD(0x23);							//wb w
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R23_DU[count]);}
   LUT_Flag=1;
 }
 else
 {
	 
	  EPD_W21_WriteCMD(0x22);							//bw r
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R23_DU[count]);}

		EPD_W21_WriteCMD(0x23);							//wb w
		for(count=0;count<56;count++)
			{EPD_W21_WriteDATA(lut_R22_DU[count]);}
   LUT_Flag=0;
	}
	 			         
}

//***************PIC_display_DU**********************//	
//Call DU waveform to refresh the screen
//***************************************************//
void PIC_display_DU(const unsigned char* picData)
{
    unsigned int i;
	
		EPD_W21_WriteCMD(0X50);   // 
		EPD_W21_WriteDATA(0xD7);  // Border	
	 
		EPD_W21_WriteCMD(0x13);	  //Transfer new data
		for(i=0;i<(Gate_Pixel*Source_Pixel/8);i++)	     
				{
					EPD_W21_WriteDATA(*picData);
					picData++;
				}	
				
				lut_DU(); 					
				EPD_refresh();						
}




//***************Clean display_GU**********************//	
//Call GC waveform to refresh the screen
//***************************************************//
void Clean_display_GC(const unsigned char Dat)
{
    unsigned int i;
    
//***********************************************************************//
//Border_Flag   Only the first screen after initialization refreshes the border, and no refreshes at other times

    if (Border_Flag==1)	
		 {
					EPD_W21_WriteCMD(0X50);      // 
					EPD_W21_WriteDATA(0xD7);     // no refreshes Border
		 }	
//***********************************************************************//

		EPD_W21_WriteCMD(0x13);		      
		for(i=0;i<(Gate_Pixel*Source_Pixel/8);i++)	     
				{
					EPD_W21_WriteDATA(Dat);
				
				}	

				lut_GC(); 				
				EPD_refresh();					
}


//***************PIC_display_GU**********************//	
//Call GC waveform to refresh the screen
//***************************************************//
void PIC_display_GC(const unsigned char* picData)
{
    unsigned int i;
    
//***********************************************************************//
////Border_Flag   Only the first screen after initialization refreshes the border, and no refreshes at other times

    if (Border_Flag==1)	
		 {
					EPD_W21_WriteCMD(0X50);      // 
					EPD_W21_WriteDATA(0xD7);     // no refreshes Border
		 }	
//***********************************************************************//

		EPD_W21_WriteCMD(0x13);		      
		for(i=0;i<(Gate_Pixel*Source_Pixel/8);i++)	     
				{
					EPD_W21_WriteDATA(*picData);
					picData++;
				}	

				lut_GC(); 				
				EPD_refresh();					
}

//***************lcd_chkstatus***********************//	
//READ BUSY Pin level = L means the screen driver chip is busy and cannot send data or instructions.
//Pin level = H means the screen driver chip is in idle state and can send data and instructions
//***************************************************//
void lcd_chkstatus(void)
{
  	while(1)
  	{
   		_nop_();
   	 	if(BUSY==1)
    		break;
  	}                        
}


void EPD_Reset(void)
{
	RST=1;
	DELAY_mS(10);	//At least 10ms delay 
	RST=0;		    // Module reset
	DELAY_mS(10);//At least 10ms delay 
	RST=1;
	DELAY_mS(10);//At least 10ms delay 
}


int	main(void)
{
			

//***************************************************************//
//Power on: Reset ---> Initialize settings ---> Use full refresh waveform to refresh the screen. The first screen after initialization must be refreshed with full refresh waveform
//***************************************************************/
				EPD_Reset();//Electronic paper IC reset
				EPD_init(); //EPD init	
				PIC_display_GC(gImage_a);//Use full refresh waveform GC to refresh the display image 1 screen		 
				DELAY_S(2);				

				EPD_Reset();//Electronic paper IC reset
				EPD_init(); //EPD init	
				PIC_display_GC(gImage_b);//Use full refresh waveform GC to refresh the display image 1 screen			 
				DELAY_S(2);	


				EPD_Reset();//Electronic paper IC reset
				EPD_init(); //EPD init	
				Clean_display_GC(0x00);//Use full refresh waveform GC to refresh the display image 1 screen			 
				DELAY_S(2);

				EPD_Reset();//Electronic paper IC reset
				EPD_init(); //EPD init	
				Clean_display_GC(0xff);//Use full refresh waveform GC to refresh the display image 1 screen			 
				DELAY_S(2);


				EPD_Reset();//Electronic paper IC reset
				EPD_init(); //EPD init	
				PIC_display_GC(gImage_1);//Use full refresh waveform GC to refresh the display image 1 screen			 
				DELAY_S(2);				
while(1)
     {	
	 	
				PIC_display_DU(gImage_1);     //Use local refresh waveform DU to locally refresh the display screen										 
				DELAY_S(2);	
				PIC_display_DU(gImage_2);     //Use local refresh waveform DU to locally refresh the display screen								 
				DELAY_S(2);	
				PIC_display_DU(gImage_3);     //Use local refresh waveform DU to locally refresh the display screen									 
				DELAY_S(2);		 
				PIC_display_DU(gImage_1);     //Use local refresh waveform DU to locally refresh the display screen							 
				DELAY_S(2);			  
				PIC_display_DU(gImage_2);     //Use local refresh waveform DU to locally refresh the display screen								 
				DELAY_S(2);	
				PIC_display_DU(gImage_3);     //Use local refresh waveform DU to locally refresh the display screen								 
				DELAY_S(2);			 		 
				PIC_display_DU(gImage_1);     //Use local refresh waveform DU to locally refresh the display screen							 
				DELAY_S(2);				 
				PIC_display_DU(gImage_2);     //Use local refresh waveform DU to locally refresh the display screen							 
				DELAY_S(2);	
				PIC_display_DU(gImage_3);     //Use local refresh waveform DU to locally refresh the display screen									  
				DELAY_S(2);				 		 				 
				PIC_display_DU(gImage_1);     //Use local refresh waveform DU to locally refresh the display screen		 
				DELAY_S(2);	
				PIC_display_GC(gImage_2);     //GC full refresh display screen 1, it is recommended to perform a full refresh after every 10 local refreshes			 
				DELAY_S(2);	
        EPD_sleep();//Go to sleep				
			
		//After entering sleep mode, a hardware reset is required to exit sleep mode.
		//After exiting sleep mode, you need to re-initialize the settings. Use GC to refresh the screen first, and then use DU to refresh the screen.				
				EPD_Reset();                //Electronic paper IC reset 		
				EPD_init();                 //EPD init	
				PIC_display_GC(gImage_1);   //EPD_picture			 
				DELAY_S(2);					
     } 
			 
}
